@@ -1,15 +1,34 @@
 #' Download annual daily averages
-#' @description Download annual daily average data from the prism project at 4km grid cell resolution for precipitation, mean, min and max temperature
-#' @param type The type of data to download, must be "ppt", "tmean", "tmin", "tmax", or "all",
-#'        which downloads "ppt", "tmin", and "tmax". Note that tmean == mean(tmin, tmax).
-#' @param years a valid numeric year, or vector of years, to download data for.  If no month is specified, year averages for that year will be downloaded
-#' @param keepZip if true, leave the downloaded zip files in your 'prism.path', if FALSE, they will be deleted
-#' @details Data is available from 1891 until 2014, however you have to download all data for years prior to 1981.  Thefore if you enter a vector of years that bounds 1981, you will automatically download all data for all years in the vector.  If the "all" parameter is set to TRUE, it will override any months entered and download all data. Data will be downloaded for all months in all the years in the vectors supplied. You must make sure that you have set up a valid download directory.  This must be set as options(prism.path = "YOURPATH")
+#' 
+#' Download annual daily average data from the prism project at 4km grid cell 
+#' resolution for precipitation, mean, min and max temperature
+#' 
+#' @param type The type of data to download, must be "ppt", "tmean", "tmin", 
+#'   "tmax", or "all", which downloads "ppt", "tmin", and "tmax". Note that 
+#'   tmean == mean(tmin, tmax).
+#'   
+#' @param years a valid numeric year, or vector of years, to download data for.  
+#'   If no month is specified, year averages for that year will be downloaded.
+#'   
+#' @param keepZip if `TRUE`, leave the downloaded zip files in your 
+#'   'prism.path', if `FALSE`, they will be deleted.
+#'   
+#' @details Data is available from 1891 until 2014, however you have to download 
+#' all data for years prior to 1981.  Therefore if you enter a vector of years 
+#' that bounds 1981, you will automatically download all data for all years in 
+#' the vector.  If the "all" parameter is set to TRUE, it will override any 
+#' months entered and download all data. Data will be downloaded for all months 
+#' in all the years in the vectors supplied. You must make sure that you have 
+#' set up a valid download directory.  This must be set as 
+#' `options(prism.path = "YOURPATH")`.
+#' 
 #' @examples \dontrun{
 #' ### Get all the data for January from 1990 to 2000
-#' # get_prism_annual(type="tmean", year = 1990:2000, keepZip=FALSE)
+#' get_prism_annual(type="tmean", year = 1990:2000, keepZip=FALSE)
 #' }
+#' 
 #' @importFrom utils download.file setTxtProgressBar txtProgressBar unzip
+#' 
 #' @export
 get_prism_annual <- function(type, years = NULL ,keepZip = TRUE){
   ### parameter and error handling
@@ -29,7 +48,7 @@ get_prism_annual <- function(type, years = NULL ,keepZip = TRUE){
     
   
   pre_1981 <- years[years<1981]
-  post_1981 <- years[years>1981]
+  post_1981 <- years[years >= 1981]
   uris_pre81 <- vector()
   uris_post81 <- vector()
   
@@ -58,7 +77,7 @@ get_prism_annual <- function(type, years = NULL ,keepZip = TRUE){
   }
   
   
-  counter <- i+1
+  counter <- length(uris_post81)+1
   
   
   ### Handle pre 1981 files
